@@ -10,7 +10,7 @@
 //! ```
 //! use wasmir::wasmir;
 //!
-//! #[wasmir(CustomDependencies.toml)]
+//! #[wasmir]
 //! mod my_module {
 //!    use wasm_bindgen::prelude::*;
 //!
@@ -40,6 +40,13 @@
 //!
 //! init().then(run)
 //! ```
+//! You can also specify WASM-dependencies like so:
+//! ```
+//! #[wasmir("
+//! [dependencies]
+//! web-sys = "*"
+//! ")]
+//! ```
 
 // Macro gets applied to module, function, struct, etc.
 // Macro calls compiler with web assembly target on code.
@@ -65,20 +72,21 @@ pub fn wasmir(attr: TokenStream, input: TokenStream) -> TokenStream {
 	);
 	let wasmir_dir = std::path::PathBuf::from(project_root.clone()).join(".wasmir");
 	create_dir_all(wasmir_dir.clone()).expect("couldn't create WASMIR temp directory");
+	let input = TokenStream2::from(input);
 
-	let attr = TokenStream2::from(attr);
-	let mut new_toml_path = String::new();
-
-	for item in attr.clone().into_iter() {
+   let mut dependencies = String::new();
+   
+	for item in input.clone().into_iter() {
 		match item {
 			TokenTree::Literal(literal) => {
-				new_toml_path = literal.to_string();
+            dependencies = literal.to_string();
+         }
+			_ => {
+				continue;
 			}
-			_ => {}
 		}
 	}
-
-	let input = TokenStream2::from(input);
+   
 	let mut module_name = String::new();
 	let mut module_stream: TokenStream2 = TokenStream2::new();
 
@@ -116,7 +124,7 @@ pub fn wasmir(attr: TokenStream, input: TokenStream) -> TokenStream {
 		.output()
 	{
 		Ok(o) => {
-			println!["{:#?}", o];
+			println!["{}", String::from_utf8(o.stderr).unwrap()];
 		}
 		Err(_) => {}
 	};
@@ -176,22 +184,15 @@ pub fn wasmir(attr: TokenStream, input: TokenStream) -> TokenStream {
 		}
 	}
 
-	if new_toml_path != "" {
-		let mut file = File::open(project_root.clone().join(new_toml_path))
-			.expect("could not open new toml file");
-		let mut buf = String::new();
-		file.read_to_string(&mut buf)
-			.expect("could not read in new toml");
-		let mut new_toml: Value = toml::from_str(&buf).expect("failed to parse new toml");
-		match new_toml.get_mut("dependencies") {
-			Some(Value::Table(deps)) => {
-				if let Some(Value::Table(lib_deps)) = cargo_toml.get_mut("dependencies") {
-					lib_deps.extend(deps.iter().map(|(k, v)| (k.clone(), v.clone())));
-				}
-			}
-			_ => {}
-		}
-	}
+   let mut dependencies_toml: Value = toml::from_str(&dependencies).expect("failed to parse dependencies toml");
+   match dependencies_toml.get_mut("dependencies") {
+      Some(Value::Table(deps)) => {
+         if let Some(Value::Table(lib_deps)) = cargo_toml.get_mut("dependencies") {
+            lib_deps.extend(deps.iter().map(|(k, v)| (k.clone(), v.clone())));
+         }
+      }
+      _ => {}
+   }
 
 	let mut file =
 		File::create(module_root.join("Cargo.toml")).expect("failed to write toml/create file");
@@ -207,7 +208,7 @@ pub fn wasmir(attr: TokenStream, input: TokenStream) -> TokenStream {
 		.output()
 	{
 		Ok(o) => {
-			println!["{:#?}", o];
+			println!["{}", String::from_utf8(o.stderr).unwrap()];
 		}
 		Err(e) => {
 			panic!["could not build: {}", e];
